==> schlix-cms-v2.1.8-7.zip: schlix/install/master.template.php <==
<?php 
    if (!defined('SCHLIX_INSTALLER')) die('Please visit /install/');
    define('TEMPLATE_PATH', '../system/themes/admindefault');
    define('SCHLIX_SYSTEM_URL_PATH', '../system');
    global $__html_title;
    
    $array_steps =
        [
          ['qry' => '', 'title' => 'Welcome' ],
          ['qry' => 'action=requirement', 'title' => 'System Requirement' ],
          ['qry' => 'action=variables', 'title' => 'Configuration' ],
          ['qry' => 'action=database', 'title' => 'Database' ],
          ['qry' => 'action=finish', 'title' => 'Finish' ]
          
        ];
?>

<!DOCTYPE HTML>
<html>
    <head>
        <meta charset="UTF-8">
        <title>SCHLIX CMS Installation | <?= $__html_title ?></title>
        <meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
        <link rel="shortcut icon" type="image/x-icon"  href="<?= TEMPLATE_PATH; ?>/icons/favicon.ico" />
        <link rel="stylesheet" type="text/css" href="../system/fonts/open-sans/open-sans.css" />
        <link rel="stylesheet" type="text/css" href="../system/fonts/font-awesome/font-awesome.min.css"  />
        <link rel="stylesheet" type="text/css" href="../system/js/bootstrap/3/bootstrap.min.css" />
        <link rel="stylesheet" type="text/css" href="install-bootstrap.css" />
        <link rel="stylesheet" type="text/css" href="install.css" />
        <script type="text/javascript" src="../system//js/jquery/jquery-2.2.4.min.js"></script>
        <script type="text/javascript" src="../system/js/bootstrap/3/bootstrap.min.js"></script>
        <script type="text/javascript" src="../system/js/schlix-ui/schlix-ui.minified.js"></script>
        <script type="text/javascript" src="../system/js/jstz/jstz.min.js"></script>
        <script type="text/javascript" src="install.js"></script>
        
    </head>
    <body>
        <div id="global-busy-indicator" class="busy-indicator-2" style="display:none"></div>

        <header class="header">
            <div class="container">
                <img src="../system/images/schlixlogo.png" border="0" align="absmiddle" /> <div class="title-step pull-right">Installation Step: <?= $__html_title ?></div>
            </div>
        </header>
        <section id="page-install" class="container">
            <?php /*<div class="row">
                <div class="col-md-4 ">
                        <ul class="navbar nav navbar-default">
                            <li><a href="index.php">1. Welcome</a></li>    
                            <li><a href="index.php?action=license">2. License Agreement</a></li>
                            <li><a href="index.php?action=requirement">3. Check Requirement</a></li>
                            <li><a href="index.php?action=variables">4. Initialize Configuration</a></li>
                            <li><a href="index.php?action=database">5. Database Installation</a></li>
                            <li><a href="index.php?action=finish">6. Finish</a></li>
                        </ul>
                </div>
                <div class="col-md-8">
                    <div class="content page-content">
                        <?= $__html_output ?>
                    </div>
                </div>
            </div>*/ ?>
            
            <div id="wid-id-0">

                <!-- widget div-->
                <div role="content">
                    <!-- widget content -->

                    <div class="wizard-header">
                        <ul class="installwizard">
                            <?php for ($i = 0; $i < ___c($array_steps); $i++): ?>
                                <?php $active = ($array_steps[$i]['qry'] == $_SERVER['QUERY_STRING']) ? 'class="active"' : '' ?>
                                <li <?= $active ?>>
                                    <a href="<?= 'index.php?' . $array_steps[$i]['qry'] ?>"  <?= $active ?>> <span class="step"><?= $i + 1 ?></span> <span class="title"><?= $array_steps[$i]['title'] ?></span> </a>
                                </li>                                        
                            <?php endfor ?>

                        </ul>
                        <div class="clearfix"></div>
                    </div>
                    <div class="content page-content">
                        <?= $__html_output ?>
                    </div>


                    <!-- end widget content -->

                </div>
                <!-- end widget div -->

            </div>
            <!-- end widget -->            
        </section>

        <footer class="footer">
            <div class="container">
            <p>IMPORTANT: By using this software, you are agreeing to the TERMS &amp; CONDITIONS in the LICENSE document. If you encounter any issue during the installation process, please visit <a href="https://www.schlix.com/forum/" target="_blank">our forum</a>.</p>
            </div>
        </footer>
    </body>
</html>

==> schlix-cms-v2.2.7-1.zip: schlix/install/master.template.php <==
<?php
if (!defined('SCHLIX_INSTALLER')) die('Please visit /install/');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//


    
    define('TEMPLATE_PATH', '../system/themes/admindefault');
    define('SCHLIX_SYSTEM_URL_PATH', '../system');
    global $__html_title;
    
    $array_steps =
        [
          ['qry' => '', 'title' => 'Welcome' ],
          ['qry' => 'action=requirement', 'title' => 'System Requirement' ],
          ['qry' => 'action=variables', 'title' => 'Configuration' ],
          ['qry' => 'action=database', 'title' => 'Database' ],
          ['qry' => 'action=finish', 'title' => 'Finish' ]
          
        ];
?>

<!DOCTYPE HTML>
<html>
    <head>
        <meta charset="UTF-8">
        <title>SCHLIX CMS Installation | <?= $__html_title ?></title>
        <meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
        <link rel="shortcut icon" type="image/x-icon"  href="<?= TEMPLATE_PATH; ?>/icons/favicon.ico" />
        <link rel="stylesheet" type="text/css" href="../system/fonts/open-sans/open-sans.css" />
        <link rel="stylesheet" type="text/css" href="../system/fonts/font-awesome/font-awesome.min.css"  />
        <link rel="stylesheet" type="text/css" href="../system/skins/bootstrap3/bootstrap.min.css" />
        <link rel="stylesheet" type="text/css" href="install-bootstrap.css" />
        <link rel="stylesheet" type="text/css" href="install.css" />
        <script type="text/javascript" src="../system//js/jquery/jquery-3.4.1.min.js"></script>
        <script type="text/javascript" src="../system/skins/bootstrap3/bootstrap.min.js"></script>
        <script type="text/javascript" src="../system/js/schlix-ui/schlix-ui.minified.js"></script>
        <script type="text/javascript" src="../system/js/jstz/jstz.min.js"></script>
        <script type="text/javascript" src="install.js"></script>
        
    </head>
    <body>
        <div class="install-schlix">
        <div id="global-busy-indicator" class="busy-indicator-2" style="display:none"></div>

        <header class="header">
            <div class="container">
                <img src="../system/images/schlixlogo.png" border="0" align="absmiddle" /> <div class="title-step pull-right">Installation Step: <?= $__html_title ?></div>
            </div>
        </header>
        <section id="page-install" class="container">
            <?php /*<div class="row">
                <div class="col-md-4 ">
                        <ul class="navbar nav navbar-default">
                            <li><a href="index.php">1. Welcome</a></li>    
                            <li><a href="index.php?action=license">2. License Agreement</a></li>
                            <li><a href="index.php?action=requirement">3. Check Requirement</a></li>
                            <li><a href="index.php?action=variables">4. Initialize Configuration</a></li>
                            <li><a href="index.php?action=database">5. Database Installation</a></li>
                            <li><a href="index.php?action=finish">6. Finish</a></li>
                        </ul>
                </div>
                <div class="col-md-8">
                    <div class="content page-content">
                        <?= $__html_output ?>
                    </div>
                </div>
            </div>*/ ?>
            
            <div id="wid-id-0">

                <!-- widget div-->
                <div role="content">
                    <!-- widget content -->

                    <div class="wizard-header">
                        <ul class="installwizard">
                            <?php for ($i = 0; $i < ___c($array_steps); $i++): ?>
                                <?php $active = ($array_steps[$i]['qry'] == $_SERVER['QUERY_STRING']) ? 'class="active"' : '' ?>
                                <li <?= $active ?>>
                                    <a href="<?= 'index.php?' . $array_steps[$i]['qry'] ?>"  <?= $active ?>> <span class="step"><?= $i + 1 ?></span> <span class="title"><?= $array_steps[$i]['title'] ?></span> </a>
                                </li>                                        
                            <?php endfor ?>

                        </ul>
                        <div class="clearfix"></div>
                    </div>
                    <div class="content page-content">
                        <?= $__html_output ?>
                    </div>


                    <!-- end widget content -->

                </div>
                <!-- end widget div -->

            </div>
            <!-- end widget -->            
        </section>

        <footer class="footer">
            <div class="container">
            <p>IMPORTANT: By using this software, you are agreeing to the TERMS &amp; CONDITIONS in the LICENSE document. If you encounter any issue during the installation process, please visit <a href="https://www.schlix.com/forum/" target="_blank">our forum</a>.</p>
            </div>
        </footer>
    </body>
    </div>
</html>
